#oython 1.0.0 
#prints 0.0.1

import time
import sys

def cleansc(nwq):#清屏
    if nwq:
        time.sleep(nwq)
        sys.stdout.write("\033[2J\033[00H")
        
def oyprint(nwz,t):#逐字输出
    for nwprint in nwz:
        time.sleep(t)
        if len(nwz) != 0:
            print(nwprint,end = '')
        else:
            print(nwprint)
    print()
    
def error(err):
    raise Exception(err)



#oython 1.0.0 
#func 0.0.1

import os
import pygame
import requests
import platform
import urllib.request
import urllib.parse
from lxml import etree

user_system = platform.system()

def broadcast(mp3,time):

    if not isinstance(mp3,str):
        err("请正确输入mp3文件地址")
    pygame.mixer.init()
    pygame.mixer.music.load(mp3)
    pygame.mixer.music.play()
    if time is not None:
        time.sleep(time)
        pygame.mixer.music.stop()
    elif time != 0:
        time.sleep(time)
        pygame.mixer.music.stop()
        

def desktop_path():
    return os.path.join(os.path.expanduser("~"), 'Desktop')+"/"
            
def save_user():
    try:
        path = desktop_path()
        file = path + "用户.txt"
        f = open(file,"x")
        us = input("请输入用户名：")
        f.write(us)
        f.close()
        fn = open(file,"r")
        fnr = fn.read()
        fn.close()
        return us
    except:
        fn = open(file,"r")
        fnr = fn.read()
        fn.close()
        return fnr

def find_letter(a,b):
    c = False
    for letter in a:
        if letter == b:
            c = True
            return True
            break
    if c == False:
        return c



import requests
import urllib.request
import urllib.parse
from lxml import etree

def translate(content):
    url = "http://fanyi.youdao.com/translate?doctype=json&type=AUTO&i="+content
    r = requests.get(url)
    result = r.json()
    return result["translateResult"][0][0]["tgt"]

def find_baike(content):
    url = 'https://baike.baidu.com/item/' + urllib.parse.quote(content)
    headers = { 
        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/67.0.3396.99 Safari/537.36' 
    }
    request = urllib.request.Request(url=url, headers=headers, method='GET')
    response = urllib.request.urlopen(request)
    txt = response.read().decode('utf-8')
    html = etree.HTML(txt)
    senlist = html.xpath('//div[contains(@class,"lemma-summary") or contains(@class,"lemmaWgt-lemmaSummary")]//text()') 
    sen_list_after_filter = [item.strip('\r') for item in senlist]
    return ''.join(sen_list_after_filter)
    



def get_copyright():
    print("All rights reserved; those responsible for unauthorized reproduction will be prosecuted。")
def get_author():
    print("author(func,prints,copyright):Li Chengze\npublisher:Guo Yanming")


import setuptools
setuptools.setup(
    name='oython',
    version='1.0.0',
    author='Chengze Li',
    author_email='gyms1111@163.com',
    description="oython库，作者:李承泽（正常线路下载失败时，请切换为python原版路线)。",
    long_descripition_content_type="text/markdown",
    url='https://github.com/',
    packages=setuptools.find_packages(),
    classifiers= [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent" ,
    ],
)